# Generated by Django 5.0 on 2023-12-13 07:03

from django.db import migrations


def migrate_mailing_lists_into_new_model(apps, schema_editor):
    """Move the bot's mailing list information from the BotSetting to the new MailingList model."""

    BotSetting = apps.get_model('api', 'BotSetting')
    MailingList = apps.get_model('api', 'MailingList')
    MailingListSeenItem = apps.get_model('api', 'MailingListSeenItem')
    try:
        setting = BotSetting.objects.get(name='news')
    except BotSetting.DoesNotExist:
        return

    # Field format:
    # {
    #   "pep": [
    #     "644",
    #     "8102",
    #     ...
    for list_name, item_hashes in setting.data.items():
        (mailing_list, _created) = MailingList.objects.get_or_create(name=list_name)
        MailingListSeenItem.objects.bulk_create(
            MailingListSeenItem(list=mailing_list, hash=item_hash)
            for item_hash in item_hashes
        )

    setting.delete()


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0093_add_mailing_lists'),
    ]

    operations = [
        migrations.RunPython(migrate_mailing_lists_into_new_model, elidable=True)
    ]
