---
title: Frequently Asked Questions
description: The Python Discord FAQ.
icon: fab fa-discord
toc: 4
---

Welcome to Python Discord! Sometimes in our channels we get similar questions asked every so often.
We've compiled the most frequently asked questions and provided our response to them.
This FAQ is aimed at answering questions about the Python Discord community. If you have question about Python, feel free to ask in `#python-general`.

## Staff & Roles

#### **Q: How do I get the helper role / become moderator / join staff?**

There are no applications to become a Helper, Moderator, Admin, or other staff role.
To become a Helper, which is our base staff role, people are nominated by a staff member and are later put up to a vote by Moderators, Admins, and Owners.
If the candidate received enough votes unanimously, then we offer them the Helper role.
This whole process takes place in channels only viewable to staff members.

Being a Helper is not only about helping people with Python questions or helping with our projects, but is also about demonstrating an understanding of our community's culture.
To read more about what we look for in a Helper and to read about our internal staff roles (Moderators, Leads, Core Developer, Admin), check out [this page](/pages/server-info/roles/).


#### **Q: What is this role on the server?**

We document the purposes of our most important roles on our website. Check it out [here](/pages/server-info/roles/).

The roles that are not documented on that page are for seasonal events. These are specific to those events and don't impact permissions on the server.


#### **Q: What perks are there for nitro boosters? Can I keep the nitro role once the boost expires?**

People who boost our server automatically get a bright cyan role color, but this is purely cosmetic and there aren't any other incentives to give us Nitro boosts.
Discord itself manages that specific role, so the role is automatically removed when the boost expires.

Patrons who donate via [our Patreon](https://www.patreon.com/python_discord) also get a blue role and this is also a purely cosmetic role.
We do appreciate our Patreon supporters and our Nitro Boosters!

We have received suggestions to give Nitro boosters non-cosmetic perks like a Nitro boosters lounge or the ability to use emoji reactions in certain channels, though that isn't something we will consider as we don't want to gate any part of the server behind a paywall.


#### **Q: I'd like to report inappropriate behavior on the server. How do I do that?**

To report inappropriate or rule-breaking behaviour on the server, please send a direct message to our `@ModMail`.
You should find the ModMail bot at the top of the server member list.
If it's an urgent situation that needs immediate moderator attention, such as spam or NSFW content, then you can ping the `@Moderators` role in the server.

## Questions about our bots

#### **Q: Can I get Python bot on my server?**

There isn't a way to invite `@Python` to other servers.
`@Python` is closely tied to our server architecture and wouldn't be able to properly function without a specific set-up.
If you are interested in `@Python` though, you can host your own instance of it.
The entire project is open source and can be found on [our github](https://github.com/python-discord/bot).

#### **Q: Who is the Dave bot?**

Dave, in addition to [learning to code](https://www.youtube.com/watch?v=ZH26PuX3re0), is running an instance of [Metricity](https://github.com/python-discord/metricity), which collects advanced metrics about the usage of the server.
Message content is not stored or collected.
You can view what data we collect in our [data privacy policy](/pages/privacy/).


#### **Q: Do any of the bots do X? Can I contribute to the bot?**

We have two bots that provide functionality in our server: `@Python` and `@Sir Lancebot`.

* `@Python` is the bot that helps manage certain server functionality (i.e. our help channel and moderation systems).
* `@Sir Lancebot` is our community bot that is designed as an entry level project for people to learn about open source contribution.
* `@Sir Lancebot` contains our fun and silly commands, like `.battleship`, `.BunnyNameGenerator`, `.http_status` which provides dog and cat HTTP status codes, and more!

You can check out [`@Python` here on github](https://github.com/python-discord/bot), and check out [`@Sir Lancebot` here](https://github.com/python-discord/sir-lancebot).
If you have any questions about how to contribute, drop by the `#dev-contrib` channel in server.

## Server Specific Questions

#### **Q: Why can't I upload a specific file type?**

The only file types that we allow on this server are those that Discord supports a native preview for.
This is because it's easier and safer for people on the server since they do not need to download a file to view it.
It's also to ease the burden on our moderators, otherwise they would have to download and check the files posted to the server.

Even though Discord does support previewing of files like `.txt` and `.py`, that support is only available on Desktop, not mobile. Additionally, we prefer people to use hastebin as it encourages them to only copy over the relevant code snippets instead of their whole code; this makes helping much easier for all involved.

If you want to share code please use our hosted hastebin, [paste.pythondiscord.com](https://paste.pythondiscord.com).


#### **Q: Why is this permission not allowed in that channel?**

Our general policy is to allow permissions unless proven that they are negatively affecting the channel.
If a certain channel doesn't have a permission, chances are it was allowed there at some point, but the cost of moderating or managing it outweighed the benefit.
Feel free to ask in `#community-meta` if you'd like the reasoning behind any specific decision.


#### **Q: Can we have a channel to show off projects or a channel to find people to work on projects with?**

We previously had these channels, though they unfortunately did not work out the way we had hoped.
Engagement was low and they were a large burden on our moderators due to the number of low quality or rule violating posts.

In general, a real-time chat client isn't the best avenue for showing off your projects or finding collaborators because messages are typically only seen by those actively engaged at the time they are posted.
You're welcome to showcase your projects in our off-topic channels or on a different platform like Reddit.


#### **Q: Can I make a recommendation about a specific feature in the server?**

If you want to make a recommendation or suggestion about the server feel free to post in `#community-meta`.
You can also open an issue on our meta repo on GitHub, which can be found [here](https://github.com/python-discord/meta).


#### **Q: Why did the icon change?**

While we love our blurple Python logo, we also enjoy celebrating other events throughout the year, like Advent of Code, Pride Month, Black History Month, Valentine's Day, Diwali, and more! In the spirit of those celebrations, we like to have some fun and change our icon instead.
If you're wondering why it's changed this time, check out `#changelog` on the server, as the reasoning for the recent change will be there.

If you'd like to contribute and create a Python Discord server icon for us to use, check out [our branding repo](https://github.com/python-discord/branding) for what we currently have and talk to us in the `#dev-branding` channel in the server.

## Misc

#### **Q: Can I interact with the data collected on the server?**

Unfortunately we don't allow direct interaction with the metrics we collect on the server.
The data we do collect is used for moderation purposes, please see [our Privacy Policy](/pages/privacy/) on what data is collected and how we use it.
Legend has it that if you say "SQL" or "graphs" enough times, a `@joe` might appear and provide some graphs and run queries you might have in mind.

We do have some public stats available to view here: [https://stats.pythondiscord.com/](https://stats.pythondiscord.com/)
