---
title: Help Channels
description: How do help channels work in the Python Discord community?
icon: fab fa-discord
relevant_links:
    Asking Good Questions: ../asking-good-questions
    Role Guide: /pages/server-info/roles
    Helping Others: ../helping-others
toc: 3
---

At Python Discord we have two different kinds of help channels: **topical help channels** and **help forum posts**.

# Topical Help Channels

In topical channels, users can ask for help regarding specific domains or areas of Python.
These channels also sometimes attract domain experts. For example, `#async-and-concurrency` has CPython contributors who helped write asyncio, and in `#game-development` you can find the creators and maintainers of several game frameworks.
If your question fits into the domain of one of our topical help channels, and if you're not in a big hurry, then this is probably the best place to ask for help.

![List of topical help channels](/static/images/content/help_channels/topical_channels.png)

Some of the topical help channels have a broad scope, so they can cover many related topics.
For example, `#data-science-and-ai` covers scientific Python, statistics, and machine learning, while `#algos-and-data-structs` covers everything from data structures and algorithms to maths.

Each channel on the server has a channel description which briefly describes the topics covered by that channel. If you're not sure where to post, feel free to ask us which channel is appropriate in `#community-meta`.

# Help Forum Posts

Help forum posts can be used for all Python-related help, and have the advantage of attracting a more diverse spectrum of helpers. There is also the added benefit of receiving individual focus and attention on your question. These posts are a great choice for generic Python help, but can be used for domain-specific Python help as well.

## How to Create A New Post

There are 4 easy needed steps to make this happen

1. Navigate to the **Python Help System** category.<br>
![Python help system category](/static/images/content/help_channels/help-system-category.png)
2. Open the **python-help** forum channel.
3. Click on the **New Post** button in the top-right corner.<br>
![New post button](/static/images/content/help_channels/new-post-button.png)
4. Choose a brief title that best describes your issue, along with a message explaining it more in details, and **post** it.
Note that you can also choose one or more tags which can help attract experts of that tag easily.<br>
![New post form](/static/images/content/help_channels/new-post-form.png)

Be sure to [ask questions with enough information](../asking-good-questions) in order to give yourself the best chances of getting help!

At this point you will have the **Help Cooldown** role which will remain on your profile until you close your newly created post. This ensures that users can only have one post at any given time, giving everyone a chance to have their question seen.

# Frequently Asked Questions

### I created a new help post, what happens now?
Once you click on `Post`, these events take place:<br>
1. A new channel will be created for you, and you'll have an `OP` next to you username, which tells people you're the `Original Poster`, or in other words, the owner of the help topic in that channel.<br>
2. Your original question/message will always be the first one in that channel.<br>
3. Our Python bot will send a message reminding you of what you should include in your question/message in case you could have missed anything.<br>
4. People will be able to jump on that channel, and you can have a discussion with anyone who's volunteering to help you by asking as many followup questions as you want.<br>

#### Example
Suppose we're trying to find the minimum value in a list of integers.
Once we've chosen our title and message content, we are ready to make a new post.<br><br>
![Filled form example](/static/images/content/help_channels/question-example.png)<br><br>
Note how we've checked the **Algos & data structs** tag here, whose circumference is highlighted in blue, since this is a question about an algorithm to find the minimum.<br>
This will greatly help others pinpoint where they can help you best based on a combination of your title and tag from a first glance.<br><br>
Once you click on post, a new channel is created, and you can see the original message on top along with the `OP` tag next to the poster's avatar.<br>
You will also see the message that our Python bot sends instantly right after yours.<br><br>
![Newly created thread example](/static/images/content/help_channels/newly-created-thread-example.png)

### How long does my help post stay active?

The post remains open for **30 minutes** after your last message, or 10 minutes after the last message sent by another user (whichever time comes later).

![Channel dormant message](/static/images/content/help_channels/dormant_message.png)
*You'll see this message in your post once it goes dormant.*

### No one answered my question. How come?

The server has users active all over the world and all hours of the day, but some time periods are less active than others. It's also possible that the users that read your question didn't have the knowledge required to help you. If no one responded, feel free to open another post a little later, or try an appropriate topical channel.

If you feel like your question is continuously being overlooked, read our guide on [asking good questions](../asking-good-questions) to increase your chances of getting a response.

### My question was answered. What do I do?

Go ahead and use one of the `!close` or `!solved` commands if you've satisfactorily solved your problem. You will only be able to run this command in your own post, and no one (outside of staff) will be able to close your post for you.

Closing your post once you are finished leads to less occupied ones, which means more attention can be given to other users that still need help.

### Can only Helpers answer help questions?

Definitely not! We encourage all members of the community to participate in giving help. If you'd like to help answer some questions, you can either browse all posts in the **python-help** forum channel or head over to the **Topical Chat/Help** category.

Before jumping in, please read our guide on [helping others](../helping-others) which explains our expectations for the culture and quailty of help that we aim for on the server.

Tip: run the `!helpdm on` command in the `#bot-commands` channel to get notified via DM with jumplinks to help posts you're participating in.

### Can I save my help session for future reference?

Yes! Because the help posts are only closed without being deleted, this means you can always refer to a previous help session if you found one particularly helpful.

Tip: reply to a message and run the `.bm` command to get bookmarks sent to you via DM for future reference.

### I lost my help post!

No need to panic. Your post was probably just closed due to inactivity.
All the dormant help posts are still available at the bottom of the **python-help** forum channel and also through search in the **Python Help System** category.
If you're not sure what the title of your help post was, you can easily find it by using the Discord Search feature.
Try searching for `from:<your nickname>` to find the last messages sent by yourself, and from there you will be able to jump directly into the channel by pressing the Jump button on your message.
